local _, AT = ...

-- file import
local Utils = AT.Utils

--[[
  NOTES:
  - Acts as static "class"
  - gets lazy set up
]]

local FrameMessageBox = {}
FrameMessageBox.frame = nil

AT.FrameMessageBox = FrameMessageBox

function FrameMessageBox:Init()
  -- create frame
  local frame = CreateFrame('Frame', nil, UIParent, 'BasicFrameTemplate')
  frame:SetFrameStrata('TOOLTIP')
  -- setup dragging
  frame:RegisterForDrag('LeftButton')
  frame:EnableMouse(true)
  frame:SetMovable(true)
  frame:SetScript('OnDragStart', frame.StartMoving)
  frame:SetScript('OnDragStop', frame.StopMovingOrSizing)

  -- create editbox
  frame.scrollFrame = CreateFrame('ScrollFrame', nil, frame, 'InputScrollFrameTemplate')
  -- workaround for an issue where this would be nil in Interface\SharedXML\SharedUIPanelTemplates.lua:674
  -- 2019-03-02, Patch 8.1
  frame.scrollFrame.EditBox.cursorOffset = 0
  frame.scrollFrame.CharCount:Hide() 
  frame.scrollFrame:ClearAllPoints()
  frame.scrollFrame:SetPoint('TOPLEFT', frame.Bg, 'TOPLEFT', 10, -10)
  frame.scrollFrame:SetPoint('BOTTOMRIGHT', frame.Bg, 'BOTTOMRIGHT', -13, 10)

  self.frame = frame
end

function FrameMessageBox:Show(aHeadline, aText)
  if self.frame == nil then
    self:Init()
  end

  local frame = self.frame

  local resW, resH = Utils:GetResolution()

  -- setup frame
  frame:SetSize(resW / 2, resH / 2)
  frame:ClearAllPoints()
  frame:SetPoint('CENTER')

  frame.TitleText:SetText(aHeadline)

  -- setup editbox
  frame.scrollFrame.EditBox:SetText(aText)
  frame.scrollFrame.EditBox:SetWidth(frame:GetWidth())
  frame.scrollFrame.EditBox:SetFontObject('ChatFontNormal')
  frame.scrollFrame.EditBox:SetCursorPosition(0)

  frame:Show()
end
